# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.ai.stt.v2 import stt_service_pb2 as yandex_dot_cloud_dot_ai_dot_stt_dot_v2_dot_stt__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class SttServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.LongRunningRecognize = channel.unary_unary(
        '/yandex.cloud.ai.stt.v2.SttService/LongRunningRecognize',
        request_serializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v2_dot_stt__service__pb2.LongRunningRecognitionRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.StreamingRecognize = channel.stream_stream(
        '/yandex.cloud.ai.stt.v2.SttService/StreamingRecognize',
        request_serializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v2_dot_stt__service__pb2.StreamingRecognitionRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v2_dot_stt__service__pb2.StreamingRecognitionResponse.FromString,
        )


class SttServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def LongRunningRecognize(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StreamingRecognize(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_SttServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'LongRunningRecognize': grpc.unary_unary_rpc_method_handler(
          servicer.LongRunningRecognize,
          request_deserializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v2_dot_stt__service__pb2.LongRunningRecognitionRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'StreamingRecognize': grpc.stream_stream_rpc_method_handler(
          servicer.StreamingRecognize,
          request_deserializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v2_dot_stt__service__pb2.StreamingRecognitionRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v2_dot_stt__service__pb2.StreamingRecognitionResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.ai.stt.v2.SttService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.compute.v1.instancegroup import instance_group_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2
from yandex.cloud.compute.v1.instancegroup import instance_group_service_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class InstanceGroupServiceStub(object):
  """A set of methods for managing InstanceGroup resources.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/yandex.cloud.compute.v1.instancegroup.InstanceGroupService/Get',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.GetInstanceGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2.InstanceGroup.FromString,
        )
    self.List = channel.unary_unary(
        '/yandex.cloud.compute.v1.instancegroup.InstanceGroupService/List',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.ListInstanceGroupsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.ListInstanceGroupsResponse.FromString,
        )
    self.Create = channel.unary_unary(
        '/yandex.cloud.compute.v1.instancegroup.InstanceGroupService/Create',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.CreateInstanceGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.CreateFromYaml = channel.unary_unary(
        '/yandex.cloud.compute.v1.instancegroup.InstanceGroupService/CreateFromYaml',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.CreateInstanceGroupFromYamlRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Update = channel.unary_unary(
        '/yandex.cloud.compute.v1.instancegroup.InstanceGroupService/Update',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.UpdateInstanceGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.UpdateFromYaml = channel.unary_unary(
        '/yandex.cloud.compute.v1.instancegroup.InstanceGroupService/UpdateFromYaml',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.UpdateInstanceGroupFromYamlRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Stop = channel.unary_unary(
        '/yandex.cloud.compute.v1.instancegroup.InstanceGroupService/Stop',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.StopInstanceGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Start = channel.unary_unary(
        '/yandex.cloud.compute.v1.instancegroup.InstanceGroupService/Start',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.StartInstanceGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Delete = channel.unary_unary(
        '/yandex.cloud.compute.v1.instancegroup.InstanceGroupService/Delete',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.DeleteInstanceGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.ListInstances = channel.unary_unary(
        '/yandex.cloud.compute.v1.instancegroup.InstanceGroupService/ListInstances',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.ListInstanceGroupInstancesRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.ListInstanceGroupInstancesResponse.FromString,
        )
    self.ListOperations = channel.unary_unary(
        '/yandex.cloud.compute.v1.instancegroup.InstanceGroupService/ListOperations',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.ListInstanceGroupOperationsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.ListInstanceGroupOperationsResponse.FromString,
        )
    self.ListLogRecords = channel.unary_unary(
        '/yandex.cloud.compute.v1.instancegroup.InstanceGroupService/ListLogRecords',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.ListInstanceGroupLogRecordsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.ListInstanceGroupLogRecordsResponse.FromString,
        )


class InstanceGroupServiceServicer(object):
  """A set of methods for managing InstanceGroup resources.
  """

  def Get(self, request, context):
    """Returns the specified InstanceGroup resource.

    To get the list of available InstanceGroup resources, make a [List] request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """Retrieves the list of InstanceGroup resources in the specified folder.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    """Creates an instance group in the specified folder.
    This method starts an operation that can be cancelled by another operation.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateFromYaml(self, request, context):
    """Creates an instance group in the specified folder from a YAML file.
    This method starts an operation that can be cancelled by another operation.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    """Updates the specified instance group.
    This method starts an operation that can be cancelled by another operation.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateFromYaml(self, request, context):
    """Updates the specified instance group from a YAML file.
    This method starts an operation that can be cancelled by another operation.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Stop(self, request, context):
    """Stops the specified instance group.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Start(self, request, context):
    """Starts the specified instance group.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    """Deletes the specified instance group.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListInstances(self, request, context):
    """Lists instances for the specified instance group.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListOperations(self, request, context):
    """Lists operations for the specified instance group.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListLogRecords(self, request, context):
    """Lists logs for the specified instance group.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_InstanceGroupServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.GetInstanceGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2.InstanceGroup.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.ListInstanceGroupsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.ListInstanceGroupsResponse.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.CreateInstanceGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'CreateFromYaml': grpc.unary_unary_rpc_method_handler(
          servicer.CreateFromYaml,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.CreateInstanceGroupFromYamlRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.UpdateInstanceGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'UpdateFromYaml': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateFromYaml,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.UpdateInstanceGroupFromYamlRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Stop': grpc.unary_unary_rpc_method_handler(
          servicer.Stop,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.StopInstanceGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Start': grpc.unary_unary_rpc_method_handler(
          servicer.Start,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.StartInstanceGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.DeleteInstanceGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'ListInstances': grpc.unary_unary_rpc_method_handler(
          servicer.ListInstances,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.ListInstanceGroupInstancesRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.ListInstanceGroupInstancesResponse.SerializeToString,
      ),
      'ListOperations': grpc.unary_unary_rpc_method_handler(
          servicer.ListOperations,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.ListInstanceGroupOperationsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.ListInstanceGroupOperationsResponse.SerializeToString,
      ),
      'ListLogRecords': grpc.unary_unary_rpc_method_handler(
          servicer.ListLogRecords,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.ListInstanceGroupLogRecordsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__service__pb2.ListInstanceGroupLogRecordsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.compute.v1.instancegroup.InstanceGroupService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.dataproc.v1 import subcluster_pb2 as yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__pb2
from yandex.cloud.dataproc.v1 import subcluster_service_pb2 as yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class SubclusterServiceStub(object):
  """A set of methods for managing Data Proc subclusters.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/yandex.cloud.dataproc.v1.SubclusterService/Get',
        request_serializer=yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__service__pb2.GetSubclusterRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__pb2.Subcluster.FromString,
        )
    self.List = channel.unary_unary(
        '/yandex.cloud.dataproc.v1.SubclusterService/List',
        request_serializer=yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__service__pb2.ListSubclustersRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__service__pb2.ListSubclustersResponse.FromString,
        )
    self.Create = channel.unary_unary(
        '/yandex.cloud.dataproc.v1.SubclusterService/Create',
        request_serializer=yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__service__pb2.CreateSubclusterRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Update = channel.unary_unary(
        '/yandex.cloud.dataproc.v1.SubclusterService/Update',
        request_serializer=yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__service__pb2.UpdateSubclusterRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Delete = channel.unary_unary(
        '/yandex.cloud.dataproc.v1.SubclusterService/Delete',
        request_serializer=yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__service__pb2.DeleteSubclusterRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )


class SubclusterServiceServicer(object):
  """A set of methods for managing Data Proc subclusters.
  """

  def Get(self, request, context):
    """Returns the specified subcluster.

    To get the list of all available subclusters, make a [SubclusterService.List] request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """Retrieves a list of subclusters in the specified cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    """Creates a subcluster in the specified cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    """Updates the specified subcluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    """Deletes the specified subcluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_SubclusterServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__service__pb2.GetSubclusterRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__pb2.Subcluster.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__service__pb2.ListSubclustersRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__service__pb2.ListSubclustersResponse.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__service__pb2.CreateSubclusterRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__service__pb2.UpdateSubclusterRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__service__pb2.DeleteSubclusterRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.dataproc.v1.SubclusterService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.vpc.v1 import security_group_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__pb2
from yandex.cloud.vpc.v1 import security_group_service_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2


class SecurityGroupServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/yandex.cloud.vpc.v1.SecurityGroupService/Get',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.GetSecurityGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__pb2.SecurityGroup.FromString,
        )
    self.List = channel.unary_unary(
        '/yandex.cloud.vpc.v1.SecurityGroupService/List',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.ListSecurityGroupsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.ListSecurityGroupsResponse.FromString,
        )
    self.Create = channel.unary_unary(
        '/yandex.cloud.vpc.v1.SecurityGroupService/Create',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.CreateSecurityGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Update = channel.unary_unary(
        '/yandex.cloud.vpc.v1.SecurityGroupService/Update',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.UpdateSecurityGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.UpdateRules = channel.unary_unary(
        '/yandex.cloud.vpc.v1.SecurityGroupService/UpdateRules',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.UpdateSecurityGroupRulesRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.UpdateRule = channel.unary_unary(
        '/yandex.cloud.vpc.v1.SecurityGroupService/UpdateRule',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.UpdateSecurityGroupRuleRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Delete = channel.unary_unary(
        '/yandex.cloud.vpc.v1.SecurityGroupService/Delete',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.DeleteSecurityGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Move = channel.unary_unary(
        '/yandex.cloud.vpc.v1.SecurityGroupService/Move',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.MoveSecurityGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.ListOperations = channel.unary_unary(
        '/yandex.cloud.vpc.v1.SecurityGroupService/ListOperations',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.ListSecurityGroupOperationsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.ListSecurityGroupOperationsResponse.FromString,
        )


class SecurityGroupServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateRules(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateRule(self, request, context):
    """update rule description or labels
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Move(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListOperations(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_SecurityGroupServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.GetSecurityGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__pb2.SecurityGroup.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.ListSecurityGroupsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.ListSecurityGroupsResponse.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.CreateSecurityGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.UpdateSecurityGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'UpdateRules': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateRules,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.UpdateSecurityGroupRulesRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'UpdateRule': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateRule,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.UpdateSecurityGroupRuleRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.DeleteSecurityGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Move': grpc.unary_unary_rpc_method_handler(
          servicer.Move,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.MoveSecurityGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'ListOperations': grpc.unary_unary_rpc_method_handler(
          servicer.ListOperations,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.ListSecurityGroupOperationsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__service__pb2.ListSecurityGroupOperationsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.vpc.v1.SecurityGroupService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.marketplace.v1.metering import image_product_usage_service_pb2 as yandex_dot_cloud_dot_marketplace_dot_v1_dot_metering_dot_image__product__usage__service__pb2


class ImageProductUsageServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Write = channel.unary_unary(
        '/yandex.cloud.marketplace.v1.metering.ImageProductUsageService/Write',
        request_serializer=yandex_dot_cloud_dot_marketplace_dot_v1_dot_metering_dot_image__product__usage__service__pb2.WriteImageProductUsageRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_marketplace_dot_v1_dot_metering_dot_image__product__usage__service__pb2.WriteImageProductUsageResponse.FromString,
        )


class ImageProductUsageServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Write(self, request, context):
    """Writes image product's usage (authenticated by user's service account)
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ImageProductUsageServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Write': grpc.unary_unary_rpc_method_handler(
          servicer.Write,
          request_deserializer=yandex_dot_cloud_dot_marketplace_dot_v1_dot_metering_dot_image__product__usage__service__pb2.WriteImageProductUsageRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_marketplace_dot_v1_dot_metering_dot_image__product__usage__service__pb2.WriteImageProductUsageResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.marketplace.v1.metering.ImageProductUsageService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.kms.v1 import symmetric_key_pb2 as yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__pb2
from yandex.cloud.kms.v1 import symmetric_key_service_pb2 as yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class SymmetricKeyServiceStub(object):
  """Set of methods for managing symmetric KMS keys.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Create = channel.unary_unary(
        '/yandex.cloud.kms.v1.SymmetricKeyService/Create',
        request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.CreateSymmetricKeyRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Get = channel.unary_unary(
        '/yandex.cloud.kms.v1.SymmetricKeyService/Get',
        request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.GetSymmetricKeyRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__pb2.SymmetricKey.FromString,
        )
    self.List = channel.unary_unary(
        '/yandex.cloud.kms.v1.SymmetricKeyService/List',
        request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeysRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeysResponse.FromString,
        )
    self.ListVersions = channel.unary_unary(
        '/yandex.cloud.kms.v1.SymmetricKeyService/ListVersions',
        request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeyVersionsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeyVersionsResponse.FromString,
        )
    self.Update = channel.unary_unary(
        '/yandex.cloud.kms.v1.SymmetricKeyService/Update',
        request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.UpdateSymmetricKeyRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Delete = channel.unary_unary(
        '/yandex.cloud.kms.v1.SymmetricKeyService/Delete',
        request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.DeleteSymmetricKeyRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.SetPrimaryVersion = channel.unary_unary(
        '/yandex.cloud.kms.v1.SymmetricKeyService/SetPrimaryVersion',
        request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.SetPrimarySymmetricKeyVersionRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.ScheduleVersionDestruction = channel.unary_unary(
        '/yandex.cloud.kms.v1.SymmetricKeyService/ScheduleVersionDestruction',
        request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ScheduleSymmetricKeyVersionDestructionRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.CancelVersionDestruction = channel.unary_unary(
        '/yandex.cloud.kms.v1.SymmetricKeyService/CancelVersionDestruction',
        request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.CancelSymmetricKeyVersionDestructionRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Rotate = channel.unary_unary(
        '/yandex.cloud.kms.v1.SymmetricKeyService/Rotate',
        request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.RotateSymmetricKeyRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.ListOperations = channel.unary_unary(
        '/yandex.cloud.kms.v1.SymmetricKeyService/ListOperations',
        request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeyOperationsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeyOperationsResponse.FromString,
        )
    self.ListAccessBindings = channel.unary_unary(
        '/yandex.cloud.kms.v1.SymmetricKeyService/ListAccessBindings',
        request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
        )
    self.SetAccessBindings = channel.unary_unary(
        '/yandex.cloud.kms.v1.SymmetricKeyService/SetAccessBindings',
        request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.UpdateAccessBindings = channel.unary_unary(
        '/yandex.cloud.kms.v1.SymmetricKeyService/UpdateAccessBindings',
        request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )


class SymmetricKeyServiceServicer(object):
  """Set of methods for managing symmetric KMS keys.
  """

  def Create(self, request, context):
    """--- control plane

    Creates a symmetric KMS key in the specified folder.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Get(self, request, context):
    """Returns the specified symmetric KMS key.

    To get the list of available symmetric KMS keys, make a [SymmetricKeyService.List] request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """Returns the list of symmetric KMS keys in the specified folder.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListVersions(self, request, context):
    """Returns the list of versions of the specified symmetric KMS key.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    """Updates the specified symmetric KMS key.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    """Deletes the specified symmetric KMS key. This action also automatically schedules
    the destruction of all of the key's versions in 72 hours.

    The key and its versions appear absent in [SymmetricKeyService.Get] and [SymmetricKeyService.List]
    requests, but can be restored within 72 hours with a request to tech support.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetPrimaryVersion(self, request, context):
    """Sets the primary version for the specified key. The primary version is used
    by default for all encrypt/decrypt operations where no version ID is specified.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ScheduleVersionDestruction(self, request, context):
    """Schedules the specified key version for destruction.

    Scheduled destruction can be cancelled with the [SymmetricKeyService.CancelVersionDestruction] method.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CancelVersionDestruction(self, request, context):
    """Cancels previously scheduled version destruction, if the version hasn't been destroyed yet.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Rotate(self, request, context):
    """Rotates the specified key: creates a new key version and makes it the primary version.
    The old version remains available for decryption of ciphertext encrypted with it.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListOperations(self, request, context):
    """Lists operations for the specified symmetric KMS key.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListAccessBindings(self, request, context):
    """Lists existing access bindings for the specified key.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetAccessBindings(self, request, context):
    """Sets access bindings for the key.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateAccessBindings(self, request, context):
    """Updates access bindings for the specified key.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_SymmetricKeyServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.CreateSymmetricKeyRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.GetSymmetricKeyRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__pb2.SymmetricKey.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeysRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeysResponse.SerializeToString,
      ),
      'ListVersions': grpc.unary_unary_rpc_method_handler(
          servicer.ListVersions,
          request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeyVersionsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeyVersionsResponse.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.UpdateSymmetricKeyRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.DeleteSymmetricKeyRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'SetPrimaryVersion': grpc.unary_unary_rpc_method_handler(
          servicer.SetPrimaryVersion,
          request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.SetPrimarySymmetricKeyVersionRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'ScheduleVersionDestruction': grpc.unary_unary_rpc_method_handler(
          servicer.ScheduleVersionDestruction,
          request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ScheduleSymmetricKeyVersionDestructionRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'CancelVersionDestruction': grpc.unary_unary_rpc_method_handler(
          servicer.CancelVersionDestruction,
          request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.CancelSymmetricKeyVersionDestructionRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Rotate': grpc.unary_unary_rpc_method_handler(
          servicer.Rotate,
          request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.RotateSymmetricKeyRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'ListOperations': grpc.unary_unary_rpc_method_handler(
          servicer.ListOperations,
          request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeyOperationsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeyOperationsResponse.SerializeToString,
      ),
      'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
          servicer.ListAccessBindings,
          request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
      ),
      'SetAccessBindings': grpc.unary_unary_rpc_method_handler(
          servicer.SetAccessBindings,
          request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateAccessBindings,
          request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.kms.v1.SymmetricKeyService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.dataproc.manager.v1 import manager_service_pb2 as yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_manager__service__pb2


class DataprocManagerServiceStub(object):
  """Data Proc manager service defifnition
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Report = channel.unary_unary(
        '/yandex.cloud.dataproc.manager.v1.DataprocManagerService/Report',
        request_serializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_manager__service__pb2.ReportRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_manager__service__pb2.ReportReply.FromString,
        )


class DataprocManagerServiceServicer(object):
  """Data Proc manager service defifnition
  """

  def Report(self, request, context):
    """Sends a status report from a host
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DataprocManagerServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Report': grpc.unary_unary_rpc_method_handler(
          servicer.Report,
          request_deserializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_manager__service__pb2.ReportRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_manager__service__pb2.ReportReply.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.dataproc.manager.v1.DataprocManagerService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.dataproc.manager.v1 import job_service_pb2 as yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2


class JobServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.ListActive = channel.unary_unary(
        '/yandex.cloud.dataproc.manager.v1.JobService/ListActive',
        request_serializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.ListJobsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.ListJobsResponse.FromString,
        )
    self.UpdateStatus = channel.unary_unary(
        '/yandex.cloud.dataproc.manager.v1.JobService/UpdateStatus',
        request_serializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.UpdateJobStatusRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.UpdateJobStatusResponse.FromString,
        )


class JobServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def ListActive(self, request, context):
    """Retrieves a list of jobs for Data Proc cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateStatus(self, request, context):
    """Currently used to update Job status.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_JobServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'ListActive': grpc.unary_unary_rpc_method_handler(
          servicer.ListActive,
          request_deserializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.ListJobsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.ListJobsResponse.SerializeToString,
      ),
      'UpdateStatus': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateStatus,
          request_deserializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.UpdateJobStatusRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.UpdateJobStatusResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.dataproc.manager.v1.JobService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.serverless.functions.v1 import function_pb2 as yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__pb2
from yandex.cloud.serverless.functions.v1 import function_service_pb2 as yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2


class FunctionServiceStub(object):
  """A set of methods for managing serverless functions.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/yandex.cloud.serverless.functions.v1.FunctionService/Get',
        request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.GetFunctionRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__pb2.Function.FromString,
        )
    self.List = channel.unary_unary(
        '/yandex.cloud.serverless.functions.v1.FunctionService/List',
        request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionsResponse.FromString,
        )
    self.Create = channel.unary_unary(
        '/yandex.cloud.serverless.functions.v1.FunctionService/Create',
        request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.CreateFunctionRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Update = channel.unary_unary(
        '/yandex.cloud.serverless.functions.v1.FunctionService/Update',
        request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.UpdateFunctionRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Delete = channel.unary_unary(
        '/yandex.cloud.serverless.functions.v1.FunctionService/Delete',
        request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.DeleteFunctionRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.GetVersion = channel.unary_unary(
        '/yandex.cloud.serverless.functions.v1.FunctionService/GetVersion',
        request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.GetFunctionVersionRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__pb2.Version.FromString,
        )
    self.GetVersionByTag = channel.unary_unary(
        '/yandex.cloud.serverless.functions.v1.FunctionService/GetVersionByTag',
        request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.GetFunctionVersionByTagRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__pb2.Version.FromString,
        )
    self.ListVersions = channel.unary_unary(
        '/yandex.cloud.serverless.functions.v1.FunctionService/ListVersions',
        request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionsVersionsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionsVersionsResponse.FromString,
        )
    self.SetTag = channel.unary_unary(
        '/yandex.cloud.serverless.functions.v1.FunctionService/SetTag',
        request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.SetFunctionTagRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.RemoveTag = channel.unary_unary(
        '/yandex.cloud.serverless.functions.v1.FunctionService/RemoveTag',
        request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.RemoveFunctionTagRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.ListTagHistory = channel.unary_unary(
        '/yandex.cloud.serverless.functions.v1.FunctionService/ListTagHistory',
        request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionTagHistoryRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionTagHistoryResponse.FromString,
        )
    self.CreateVersion = channel.unary_unary(
        '/yandex.cloud.serverless.functions.v1.FunctionService/CreateVersion',
        request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.CreateFunctionVersionRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.ListRuntimes = channel.unary_unary(
        '/yandex.cloud.serverless.functions.v1.FunctionService/ListRuntimes',
        request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListRuntimesRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListRuntimesResponse.FromString,
        )
    self.ListOperations = channel.unary_unary(
        '/yandex.cloud.serverless.functions.v1.FunctionService/ListOperations',
        request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionOperationsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionOperationsResponse.FromString,
        )
    self.ListAccessBindings = channel.unary_unary(
        '/yandex.cloud.serverless.functions.v1.FunctionService/ListAccessBindings',
        request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
        )
    self.SetAccessBindings = channel.unary_unary(
        '/yandex.cloud.serverless.functions.v1.FunctionService/SetAccessBindings',
        request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.UpdateAccessBindings = channel.unary_unary(
        '/yandex.cloud.serverless.functions.v1.FunctionService/UpdateAccessBindings',
        request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )


class FunctionServiceServicer(object):
  """A set of methods for managing serverless functions.
  """

  def Get(self, request, context):
    """Returns the specified function.

    To get the list of all available functions, make a [List] request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """Retrieves the list of functions in the specified folder.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    """Creates a function in the specified folder.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    """Updates the specified function.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    """Deletes the specified function.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetVersion(self, request, context):
    """Returns the specified version of a function.

    To get the list of available version, make a [ListVersions] request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetVersionByTag(self, request, context):
    """Returns all versions with the specified tag.

    To get the list of all available versions, make a [ListVersions] request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListVersions(self, request, context):
    """Retrieves the list of versions for the specified function, or of all function versions
    in the specified folder.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetTag(self, request, context):
    """Set a tag for the specified version of a function.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RemoveTag(self, request, context):
    """Remove a tag from the specified version of a function.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListTagHistory(self, request, context):
    """Returns the log of tags assigned to versions of the specified function.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateVersion(self, request, context):
    """Creates a version for the specified function.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListRuntimes(self, request, context):
    """Lists available runtime environments for the specified function.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListOperations(self, request, context):
    """Lists operations for the specified function.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListAccessBindings(self, request, context):
    """Lists existing access bindings for the specified function.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetAccessBindings(self, request, context):
    """Sets access bindings for the function.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateAccessBindings(self, request, context):
    """Updates access bindings for the specified function.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_FunctionServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.GetFunctionRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__pb2.Function.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionsResponse.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.CreateFunctionRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.UpdateFunctionRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.DeleteFunctionRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'GetVersion': grpc.unary_unary_rpc_method_handler(
          servicer.GetVersion,
          request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.GetFunctionVersionRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__pb2.Version.SerializeToString,
      ),
      'GetVersionByTag': grpc.unary_unary_rpc_method_handler(
          servicer.GetVersionByTag,
          request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.GetFunctionVersionByTagRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__pb2.Version.SerializeToString,
      ),
      'ListVersions': grpc.unary_unary_rpc_method_handler(
          servicer.ListVersions,
          request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionsVersionsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionsVersionsResponse.SerializeToString,
      ),
      'SetTag': grpc.unary_unary_rpc_method_handler(
          servicer.SetTag,
          request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.SetFunctionTagRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'RemoveTag': grpc.unary_unary_rpc_method_handler(
          servicer.RemoveTag,
          request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.RemoveFunctionTagRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'ListTagHistory': grpc.unary_unary_rpc_method_handler(
          servicer.ListTagHistory,
          request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionTagHistoryRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionTagHistoryResponse.SerializeToString,
      ),
      'CreateVersion': grpc.unary_unary_rpc_method_handler(
          servicer.CreateVersion,
          request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.CreateFunctionVersionRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'ListRuntimes': grpc.unary_unary_rpc_method_handler(
          servicer.ListRuntimes,
          request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListRuntimesRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListRuntimesResponse.SerializeToString,
      ),
      'ListOperations': grpc.unary_unary_rpc_method_handler(
          servicer.ListOperations,
          request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionOperationsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionOperationsResponse.SerializeToString,
      ),
      'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
          servicer.ListAccessBindings,
          request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
      ),
      'SetAccessBindings': grpc.unary_unary_rpc_method_handler(
          servicer.SetAccessBindings,
          request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateAccessBindings,
          request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.serverless.functions.v1.FunctionService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.vpc.v1 import route_table_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__pb2
from yandex.cloud.vpc.v1 import route_table_service_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__service__pb2


class RouteTableServiceStub(object):
  """A set of methods for managing RouteTable resources.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/yandex.cloud.vpc.v1.RouteTableService/Get',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__service__pb2.GetRouteTableRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__pb2.RouteTable.FromString,
        )
    self.List = channel.unary_unary(
        '/yandex.cloud.vpc.v1.RouteTableService/List',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__service__pb2.ListRouteTablesRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__service__pb2.ListRouteTablesResponse.FromString,
        )
    self.Create = channel.unary_unary(
        '/yandex.cloud.vpc.v1.RouteTableService/Create',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__service__pb2.CreateRouteTableRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Update = channel.unary_unary(
        '/yandex.cloud.vpc.v1.RouteTableService/Update',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__service__pb2.UpdateRouteTableRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Delete = channel.unary_unary(
        '/yandex.cloud.vpc.v1.RouteTableService/Delete',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__service__pb2.DeleteRouteTableRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.ListOperations = channel.unary_unary(
        '/yandex.cloud.vpc.v1.RouteTableService/ListOperations',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__service__pb2.ListRouteTableOperationsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__service__pb2.ListRouteTableOperationsResponse.FromString,
        )
    self.Move = channel.unary_unary(
        '/yandex.cloud.vpc.v1.RouteTableService/Move',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__service__pb2.MoveRouteTableRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )


class RouteTableServiceServicer(object):
  """A set of methods for managing RouteTable resources.
  """

  def Get(self, request, context):
    """Returns the specified RouteTable resource.

    To get the list of available RouteTable resources, make a [List] request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """Retrieves the list of RouteTable resources in the specified folder.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    """Creates a route table in the specified folder and network.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    """Updates the specified route table.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    """Deletes the specified route table.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListOperations(self, request, context):
    """List operations for the specified route table.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Move(self, request, context):
    """Move route table to another folder.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_RouteTableServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__service__pb2.GetRouteTableRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__pb2.RouteTable.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__service__pb2.ListRouteTablesRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__service__pb2.ListRouteTablesResponse.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__service__pb2.CreateRouteTableRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__service__pb2.UpdateRouteTableRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__service__pb2.DeleteRouteTableRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'ListOperations': grpc.unary_unary_rpc_method_handler(
          servicer.ListOperations,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__service__pb2.ListRouteTableOperationsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__service__pb2.ListRouteTableOperationsResponse.SerializeToString,
      ),
      'Move': grpc.unary_unary_rpc_method_handler(
          servicer.Move,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__service__pb2.MoveRouteTableRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.vpc.v1.RouteTableService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.compute.v1 import instance_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2
from yandex.cloud.compute.v1 import instance_service_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class InstanceServiceStub(object):
  """A set of methods for managing Instance resources.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/yandex.cloud.compute.v1.InstanceService/Get',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2.Instance.FromString,
        )
    self.List = channel.unary_unary(
        '/yandex.cloud.compute.v1.InstanceService/List',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesResponse.FromString,
        )
    self.Create = channel.unary_unary(
        '/yandex.cloud.compute.v1.InstanceService/Create',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.CreateInstanceRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Update = channel.unary_unary(
        '/yandex.cloud.compute.v1.InstanceService/Update',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Delete = channel.unary_unary(
        '/yandex.cloud.compute.v1.InstanceService/Delete',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DeleteInstanceRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.UpdateMetadata = channel.unary_unary(
        '/yandex.cloud.compute.v1.InstanceService/UpdateMetadata',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceMetadataRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.GetSerialPortOutput = channel.unary_unary(
        '/yandex.cloud.compute.v1.InstanceService/GetSerialPortOutput',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceSerialPortOutputRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceSerialPortOutputResponse.FromString,
        )
    self.Stop = channel.unary_unary(
        '/yandex.cloud.compute.v1.InstanceService/Stop',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.StopInstanceRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Start = channel.unary_unary(
        '/yandex.cloud.compute.v1.InstanceService/Start',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.StartInstanceRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Restart = channel.unary_unary(
        '/yandex.cloud.compute.v1.InstanceService/Restart',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.RestartInstanceRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.AttachDisk = channel.unary_unary(
        '/yandex.cloud.compute.v1.InstanceService/AttachDisk',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AttachInstanceDiskRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.DetachDisk = channel.unary_unary(
        '/yandex.cloud.compute.v1.InstanceService/DetachDisk',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DetachInstanceDiskRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.AddOneToOneNat = channel.unary_unary(
        '/yandex.cloud.compute.v1.InstanceService/AddOneToOneNat',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AddInstanceOneToOneNatRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.RemoveOneToOneNat = channel.unary_unary(
        '/yandex.cloud.compute.v1.InstanceService/RemoveOneToOneNat',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.RemoveInstanceOneToOneNatRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.UpdateNetworkInterface = channel.unary_unary(
        '/yandex.cloud.compute.v1.InstanceService/UpdateNetworkInterface',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateNetworkInterfaceRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.ListOperations = channel.unary_unary(
        '/yandex.cloud.compute.v1.InstanceService/ListOperations',
        request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstanceOperationsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstanceOperationsResponse.FromString,
        )


class InstanceServiceServicer(object):
  """A set of methods for managing Instance resources.
  """

  def Get(self, request, context):
    """Returns the specified Instance resource.

    To get the list of available Instance resources, make a [List] request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """Retrieves the list of Instance resources in the specified folder.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    """Creates an instance in the specified folder.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    """Updates the specified instance.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    """Deletes the specified instance.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateMetadata(self, request, context):
    """Updates the metadata of the specified instance.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetSerialPortOutput(self, request, context):
    """Returns the serial port output of the specified Instance resource.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Stop(self, request, context):
    """Stops the running instance.

    You can start the instance later using the [InstanceService.Start] method.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Start(self, request, context):
    """Starts the stopped instance.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Restart(self, request, context):
    """Restarts the running instance.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AttachDisk(self, request, context):
    """Attaches the disk to the instance.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DetachDisk(self, request, context):
    """Detaches the disk from the instance.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddOneToOneNat(self, request, context):
    """net

    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RemoveOneToOneNat(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateNetworkInterface(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListOperations(self, request, context):
    """Lists operations for the specified instance.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_InstanceServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2.Instance.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesResponse.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.CreateInstanceRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DeleteInstanceRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'UpdateMetadata': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateMetadata,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceMetadataRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'GetSerialPortOutput': grpc.unary_unary_rpc_method_handler(
          servicer.GetSerialPortOutput,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceSerialPortOutputRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceSerialPortOutputResponse.SerializeToString,
      ),
      'Stop': grpc.unary_unary_rpc_method_handler(
          servicer.Stop,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.StopInstanceRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Start': grpc.unary_unary_rpc_method_handler(
          servicer.Start,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.StartInstanceRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Restart': grpc.unary_unary_rpc_method_handler(
          servicer.Restart,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.RestartInstanceRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'AttachDisk': grpc.unary_unary_rpc_method_handler(
          servicer.AttachDisk,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AttachInstanceDiskRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'DetachDisk': grpc.unary_unary_rpc_method_handler(
          servicer.DetachDisk,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DetachInstanceDiskRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'AddOneToOneNat': grpc.unary_unary_rpc_method_handler(
          servicer.AddOneToOneNat,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AddInstanceOneToOneNatRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'RemoveOneToOneNat': grpc.unary_unary_rpc_method_handler(
          servicer.RemoveOneToOneNat,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.RemoveInstanceOneToOneNatRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'UpdateNetworkInterface': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateNetworkInterface,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateNetworkInterfaceRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'ListOperations': grpc.unary_unary_rpc_method_handler(
          servicer.ListOperations,
          request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstanceOperationsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstanceOperationsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.compute.v1.InstanceService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.k8s.v1 import node_group_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2
from yandex.cloud.k8s.v1 import node_group_service_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class NodeGroupServiceStub(object):
  """A set of methods for managing node groups.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/yandex.cloud.k8s.v1.NodeGroupService/Get',
        request_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.GetNodeGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2.NodeGroup.FromString,
        )
    self.List = channel.unary_unary(
        '/yandex.cloud.k8s.v1.NodeGroupService/List',
        request_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupsResponse.FromString,
        )
    self.Create = channel.unary_unary(
        '/yandex.cloud.k8s.v1.NodeGroupService/Create',
        request_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.CreateNodeGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Update = channel.unary_unary(
        '/yandex.cloud.k8s.v1.NodeGroupService/Update',
        request_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.UpdateNodeGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Delete = channel.unary_unary(
        '/yandex.cloud.k8s.v1.NodeGroupService/Delete',
        request_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.DeleteNodeGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.ListOperations = channel.unary_unary(
        '/yandex.cloud.k8s.v1.NodeGroupService/ListOperations',
        request_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupOperationsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupOperationsResponse.FromString,
        )
    self.ListNodes = channel.unary_unary(
        '/yandex.cloud.k8s.v1.NodeGroupService/ListNodes',
        request_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupNodesRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupNodesResponse.FromString,
        )


class NodeGroupServiceServicer(object):
  """A set of methods for managing node groups.
  """

  def Get(self, request, context):
    """Returns the specified node group.

    To get the list of available node group, make a [List] request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """Retrieves the list of node group in the specified Kubernetes cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    """Creates a node group in the specified Kubernetes cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    """Updates the specified node group.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    """Deletes the specified node group.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListOperations(self, request, context):
    """Lists operations for the specified node group.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListNodes(self, request, context):
    """Retrieves the list of nodes in the specified Kubernetes cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_NodeGroupServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.GetNodeGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2.NodeGroup.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupsResponse.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.CreateNodeGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.UpdateNodeGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.DeleteNodeGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'ListOperations': grpc.unary_unary_rpc_method_handler(
          servicer.ListOperations,
          request_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupOperationsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupOperationsResponse.SerializeToString,
      ),
      'ListNodes': grpc.unary_unary_rpc_method_handler(
          servicer.ListNodes,
          request_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupNodesRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupNodesResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.k8s.v1.NodeGroupService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.kms.v1 import symmetric_crypto_service_pb2 as yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2


class SymmetricCryptoServiceStub(object):
  """--- Data plane for KMS symmetric cryptography operations

  Set of methods that perform symmetric encryption and decryption.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Encrypt = channel.unary_unary(
        '/yandex.cloud.kms.v1.SymmetricCryptoService/Encrypt',
        request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricEncryptRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricEncryptResponse.FromString,
        )
    self.Decrypt = channel.unary_unary(
        '/yandex.cloud.kms.v1.SymmetricCryptoService/Decrypt',
        request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricDecryptRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricDecryptResponse.FromString,
        )
    self.ReEncrypt = channel.unary_unary(
        '/yandex.cloud.kms.v1.SymmetricCryptoService/ReEncrypt',
        request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricReEncryptRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricReEncryptResponse.FromString,
        )
    self.GenerateDataKey = channel.unary_unary(
        '/yandex.cloud.kms.v1.SymmetricCryptoService/GenerateDataKey',
        request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.GenerateDataKeyRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.GenerateDataKeyResponse.FromString,
        )


class SymmetricCryptoServiceServicer(object):
  """--- Data plane for KMS symmetric cryptography operations

  Set of methods that perform symmetric encryption and decryption.
  """

  def Encrypt(self, request, context):
    """Encrypts given plaintext with the specified key.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Decrypt(self, request, context):
    """Decrypts the given ciphertext with the specified key.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ReEncrypt(self, request, context):
    """Re-encrypts a ciphertext with the specified KMS key.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GenerateDataKey(self, request, context):
    """Generates a new symmetric data encryption key (not a KMS key) and returns
    the generated key as plaintext and as ciphertext encrypted with the specified symmetric KMS key.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_SymmetricCryptoServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Encrypt': grpc.unary_unary_rpc_method_handler(
          servicer.Encrypt,
          request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricEncryptRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricEncryptResponse.SerializeToString,
      ),
      'Decrypt': grpc.unary_unary_rpc_method_handler(
          servicer.Decrypt,
          request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricDecryptRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricDecryptResponse.SerializeToString,
      ),
      'ReEncrypt': grpc.unary_unary_rpc_method_handler(
          servicer.ReEncrypt,
          request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricReEncryptRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricReEncryptResponse.SerializeToString,
      ),
      'GenerateDataKey': grpc.unary_unary_rpc_method_handler(
          servicer.GenerateDataKey,
          request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.GenerateDataKeyRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.GenerateDataKeyResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.kms.v1.SymmetricCryptoService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.mdb.mysql.v1alpha import database_pb2 as yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_database__pb2
from yandex.cloud.mdb.mysql.v1alpha import database_service_pb2 as yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_database__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class DatabaseServiceStub(object):
  """A set of methods for managing MySQL databases.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1alpha.DatabaseService/Get',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_database__service__pb2.GetDatabaseRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_database__pb2.Database.FromString,
        )
    self.List = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1alpha.DatabaseService/List',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_database__service__pb2.ListDatabasesRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_database__service__pb2.ListDatabasesResponse.FromString,
        )
    self.Create = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1alpha.DatabaseService/Create',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_database__service__pb2.CreateDatabaseRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Delete = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1alpha.DatabaseService/Delete',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_database__service__pb2.DeleteDatabaseRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )


class DatabaseServiceServicer(object):
  """A set of methods for managing MySQL databases.
  """

  def Get(self, request, context):
    """Returns the specified MySQL database.

    To get the list of available MySQL databases, make a [List] request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """Retrieves the list of MySQL databases in the specified cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    """Creates a new MySQL database in the specified cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    """Deletes the specified MySQL database.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DatabaseServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_database__service__pb2.GetDatabaseRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_database__pb2.Database.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_database__service__pb2.ListDatabasesRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_database__service__pb2.ListDatabasesResponse.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_database__service__pb2.CreateDatabaseRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_database__service__pb2.DeleteDatabaseRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.mdb.mysql.v1alpha.DatabaseService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.ai.vision.v1 import vision_service_pb2 as yandex_dot_cloud_dot_ai_dot_vision_dot_v1_dot_vision__service__pb2


class VisionServiceStub(object):
  """A set of methods for the Yandex Vision service.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.BatchAnalyze = channel.unary_unary(
        '/yandex.cloud.ai.vision.v1.VisionService/BatchAnalyze',
        request_serializer=yandex_dot_cloud_dot_ai_dot_vision_dot_v1_dot_vision__service__pb2.BatchAnalyzeRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_ai_dot_vision_dot_v1_dot_vision__service__pb2.BatchAnalyzeResponse.FromString,
        )


class VisionServiceServicer(object):
  """A set of methods for the Yandex Vision service.
  """

  def BatchAnalyze(self, request, context):
    """Analyzes a batch of images and returns results with annotations.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_VisionServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'BatchAnalyze': grpc.unary_unary_rpc_method_handler(
          servicer.BatchAnalyze,
          request_deserializer=yandex_dot_cloud_dot_ai_dot_vision_dot_v1_dot_vision__service__pb2.BatchAnalyzeRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_ai_dot_vision_dot_v1_dot_vision__service__pb2.BatchAnalyzeResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.ai.vision.v1.VisionService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
